pub struct PyStreamingFeatherWriter { /* private fields */ }Expand description
Python binding for the Rust FeatherWriter.
This provides a streaming writer of Nautilus objects into feather files with rotation
capabilities, matching the interface of Python’s StreamingFeatherWriter.
Implementations
Sourceimpl PyStreamingFeatherWriter
impl PyStreamingFeatherWriter
Sourcepub fn new(
path: String,
cache: PyCache,
clock: PyClock,
fs_protocol: Option<&str>,
fs_storage_options: Option<HashMap<String, String>>,
include_types: Option<Vec<String>>,
rotation_mode: u8,
max_file_size: u64,
rotation_interval_ns: Option<u64>,
rotation_time_ns: Option<u64>,
rotation_timezone: &str,
flush_interval_ms: Option<u64>,
replace: bool,
) -> PyResult<Self>
pub fn new( path: String, cache: PyCache, clock: PyClock, fs_protocol: Option<&str>, fs_storage_options: Option<HashMap<String, String>>, include_types: Option<Vec<String>>, rotation_mode: u8, max_file_size: u64, rotation_interval_ns: Option<u64>, rotation_time_ns: Option<u64>, rotation_timezone: &str, flush_interval_ms: Option<u64>, replace: bool, ) -> PyResult<Self>
Creates a new StreamingFeatherWriter instance.
Parameters
path: The path to persist the stream to. Must be a directory.cache: The cache for query info (PyCache).clock: The clock to use for time-related operations (PyClock).fs_protocol: Optional filesystem protocol (default: “file”).fs_storage_options: Optional storage options for cloud backends.include_types: Optional list of type names to include (e.g., [“quotes”, “trades”]).rotation_mode: Rotation mode (0=SIZE, 1=INTERVAL, 2=SCHEDULED_DATES, 3=NO_ROTATION).max_file_size: Maximum file size in bytes before rotation (for SIZE mode).rotation_interval_ns: Rotation interval in nanoseconds (for INTERVAL/SCHEDULED_DATES modes).rotation_time_ns: Scheduled rotation time in nanoseconds (for SCHEDULED_DATES mode).flush_interval_ms: Flush interval in milliseconds (default: 1000). Set to 0 to disable auto-flush.replace: If existing files at the given path should be replaced (default: False).
Sourcepub fn subscribe(&mut self) -> PyResult<()>
pub fn subscribe(&mut self) -> PyResult<()>
Subscribes to all messages on the message bus (pattern “*”).
This matches the behavior of Python’s StreamingFeatherWriter when subscribed
via trader.subscribe("*", writer.write).
Sourcepub fn unsubscribe(&mut self) -> PyResult<()>
pub fn unsubscribe(&mut self) -> PyResult<()>
Unsubscribes from the message bus.
Sourcepub fn write(&self, py: Python<'_>, data: Py<PyAny>) -> PyResult<()>
pub fn write(&self, py: Python<'_>, data: Py<PyAny>) -> PyResult<()>
Writes a data object to the stream.
Parameters
data: The data object to write (must be a Nautilus data type from pyo3).
Sourcepub fn flush(&self) -> PyResult<()>
pub fn flush(&self) -> PyResult<()>
Flushes all active buffers by writing any remaining buffered bytes to the object store.
This is called automatically based on flush_interval_ms if configured, but can also
be called manually by the client.
Sourcepub fn close(&self) -> PyResult<()>
pub fn close(&self) -> PyResult<()>
Closes all writers by flushing and removing them.
After calling this, no further writes should be performed.
Sourcepub fn is_closed(&self) -> bool
pub fn is_closed(&self) -> bool
Returns whether the writer has been closed (no active writers).